@@ -1,7 +1,7 @@
 # @Author: chunyang.xu
 # @Email:  398745129@qq.com
 # @Date:   2020-06-02 18:46:58
-# @Last Modified time: 2020-07-01 15:23:11
+# @Last Modified time: 2020-07-02 17:34:43
 # @github: https://github.com/longfengpili
 
 #!/usr/bin/env python3
@@ -60,10 +60,16 @@ class DBbase(object):
 
         Returns:
             rows {[int]} -- [影响的行数]
-            result {[list]} -- [返回的结果]
+            results {[list]} -- [返回的结果]
         '''
+        def cur_getresults(cur, count):
+            results = cur.fetchmany(count) if count else cur.fetchall()
+            results = list(results) if results else []
+            columns = tuple(map(lambda x: x[0], cur.description)) #列名
+            return columns, results
+
         rows = 0
-        result = None
+        results = None
         conn = self.get_conn()
         # dblogger.info(conn)
         cur = conn.cursor()
@@ -76,28 +82,25 @@ class DBbase(object):
             parser = SqlParse(sql)
             comment, sql, action, tablename = parser.comment, parser.sql, parser.action, parser.tablename
             if verbose:
-                dblogger.info(f"【{idx}】({action}){tablename}::{comment}")
+                dblogger.info(f"Start 【{idx}】({action}){tablename}::{comment}")
+
             self.__execute_step(cur, sql)
-            if idx == sqls_length - 1 and action == 'SELECT':
-                result = cur.fetchmany(count) if count else cur.fetchall()
-                result = list(result) if result else []
-                columns = tuple(map(lambda x: x[0], cur.description)) #列名
-                result.insert(0, columns)
-            elif verbose and action == 'SELECT':
-                result = cur.fetchmany(10)
-                result = list(result) if result else []
-                columns = tuple(map(lambda x: x[0], cur.description)) #列名
-                dblogger.info(f"\n{pd.DataFrame(result, columns=columns)}")
+
+            if action == "SELECT":
+                columns, results = cur_getresults(cur, count)
+                if idx == sqls_length - 1 or verbose:
+                    dblogger.info(f"\n{pd.DataFrame(results, columns=columns)}")
+                    results.insert(0, columns)
+                    
         try:
             conn.commit()
         except Exception as e:
             dblogger.error(e)
             conn.rollback()
-            
         rows = cur.rowcount
         conn.close()
 
-        return rows, action, result
+        return rows, action, results
 
 
 class DBCommon(DBbase):
