@@ -1,7 +1,7 @@
 # @Author: chunyang.xu
 # @Email:  398745129@qq.com
 # @Date:   2020-06-08 11:55:54
-# @Last Modified time: 2020-06-28 12:07:34
+# @Last Modified time: 2020-08-10 18:50:08
 # @github: https://github.com/longfengpili
 
 #!/usr/bin/env python3
@@ -9,6 +9,7 @@
 
 import os
 import pandas as pd
+import time
 
 from .base import DBbase
 from pydbapi.sql import SqlFileParse
@@ -27,22 +28,25 @@ class DBFileExec(DBbase):
 
     def get_filesqls(self, filepath, **kw):
         sqlfileparser = SqlFileParse(filepath)
-        sqls = sqlfileparser.get_sqls(**kw)
-        return sqls
+        arguments, sqls = sqlfileparser.get_filesqls(**kw)
+        return arguments, sqls
 
     def file_exec(self, filepath, **kw):
+        st = time.time()
         results = {}
-        sqls = self.get_filesqls(filepath, **kw)
         filename = os.path.basename(filepath)
+        dblogger.info(f"Start Job 【{filename}】".center(80, '='))
+        arguments, sqls = self.get_filesqls(filepath, **kw)
+        dblogger.info(f"【Final Arguments】The file 【{filename}】 Use arguments {arguments}")
         for desc, sql in sqls.items():
-            dblogger.info(f"Start Job 【{filename}】{desc}".center(80, '='))
+            dblogger.info(f"Start {desc}")
             verbose = True if 'verbose' in desc or filename.startswith('test') \
                         or filename.endswith('test.sql') else False
-            # dblogger.info(f"{os.path.basename(filepath)}=={progress}")
             rows, action, result = self.execute(sql, verbose=verbose)
             results[desc] = result
-            if action == 'SELECT' and verbose:
-                dblogger.info(f"【rows】: {rows}, 【action】: {action}, 【result】: \n{pd.DataFrame(result[1:], columns=result[0]).head()}")
-            dblogger.info(f"End Job 【{filename}】{desc}".center(80, '='))
+            dblogger.info(f"End {desc}")
+
+        et = time.time()
+        dblogger.info(f"End Job 【{filename}】, cost {et - st:.2f} seconds".center(80, '='))
         return results
 
